within FluidDissipation.HeatTransfer.HeatExchanger;
function kc_tubeBundle_1ph_KC
  "Heat transfer for a lateral flow through a tube bundle with more than 10 rows (laminar and turbulent flow schemes)"
  extends Modelica.Icons.Function;
  //SOURCE: Gnielinski, V.. Heat Transfer in laterally passed single tube rows and tube bundles (in German). in VDI-Waermeatlas, 9th edition, VDI-Verlag, 2002.
  //input records
  input FluidDissipation.HeatTransfer.HeatExchanger.kc_tubeBundle_1ph_IN_con IN_con
    "Input record for function kc_FilmCondensationTubeBundle"
    annotation (Dialog(group="Constant inputs"));
  input FluidDissipation.HeatTransfer.HeatExchanger.kc_tubeBundle_1ph_IN_var IN_var
    "Input record for function kc_FilmCondensationTubeBundle"
    annotation (Dialog(group="Variable inputs"));

  output Modelica.SIunits.CoefficientOfHeatTransfer kc;

protected
  Real MIN=1e-5;
  Real Nu_L_lam "Nusselt number of laminar flow, one tube";
  Real Nu_L_turb "Nusselt number of turbulent flow, one tube";
  Real Nu_L "Nusselt number one tube";
  Real Re_L "Laminar Reynolds number one tube";
  Real Pr "Prandtl number of fluid";
  Real Pr_w "Prandtl number of fluid near wall";
  Real fa "Alignment factor";
  SI.Length L "Characteristic length";
  Real a "Longitudinal alignment ratio";
  Real b "Perpendicular alignment ratio";
  Real psi "Void ratio";
  Real K "Heat flow direction coefficient";
algorithm

  a:=IN_con.s_1/IN_con.d;
  b:=IN_con.s_2/IN_con.d;
  // b<=0 refers to single row case!
  psi:=if b >= 1 or b<=0 then 1 - Modelica.Constants.pi/4/a else 1 - Modelica.Constants.pi/4/a/b;
  L:=Modelica.Constants.pi/2*IN_con.d;
  Re_L :=abs(IN_var.m_flow)/IN_con.A_front/IN_var.rho*L/psi/IN_var.eta*IN_var.rho;
  Pr   :=IN_var.eta*IN_var.cp/max(MIN,IN_var.lambda);
  Pr_w   :=IN_var.eta_w*IN_var.cp_w/max(MIN,IN_var.lambda_w);
  Nu_L_lam :=0.664*sqrt(Re_L)*max(MIN,Pr)^(1/3);
  Nu_L_turb :=(0.037*Re_L^0.8*Pr)/(1 + 2.443*max(MIN,Re_L)^(-0.1)*(max(MIN,Pr)^(2/3) - 1));
  K :=if Pr/Pr_w > 1 then (max(MIN,Pr/Pr_w))^0.25 else (max(MIN,Pr/Pr_w))^0.11;
  Nu_L :=(0.3 + sqrt((Nu_L_lam^2 + Nu_L_turb^2)));
  if IN_con.staggeredAlignment then
    fa := 1 + (if b>0 then 2/3/b else 0);
  else
    fa := 1 + (if b>0 then 0.7/psi^1.5*(b/a - 0.3)/(b/a + 0.7)^2 else 0);
  end if;
  //kc := fa;
  kc:= Nu_L*IN_var.lambda/L*K*(if IN_con.n>=10 then 1 else (((IN_con.n-1)*fa+1)/IN_con.n));
  annotation (smoothOrder(normallyConstant=IN_con) = 5, Documentation(info="<html>
<p><b><font style=\"color: #ef9b13; \">References</font></b> </p>
<p>Gnielinski, V.. <b>Heat Transfer in laterally passed single tube rows and tube bundles </b> (in German). in VDI-Waermeatlas, 9th edition, VDI-Verlag, 2002.</p>
</html>"));
end kc_tubeBundle_1ph_KC;
